@@ -48,7 +48,7 @@
 #if !defined(TQT_MODULE_XML) || defined( QT_LICENSE_PROFESSIONAL ) || defined( QT_INTERNAL_XML )
 #define TQM_EXPORT_DOM
 #else
-#define TQM_EXPORT_DOM Q_EXPORT
+#define TQM_EXPORT_DOM TQ_EXPORT
 #endif
 
 #ifndef TQT_NO_DOM
