@@ -546,11 +546,11 @@
     </message>
     <message>
         <source>Could not read from the file</source>
-        <translation>Не удается прочитать из файла</translation>
+        <translation>Не удаётся прочитать из файла</translation>
     </message>
     <message>
         <source>Could not write to the file</source>
-        <translation>Не удается записать в файл</translation>
+        <translation>Не удаётся записать в файл</translation>
     </message>
     <message>
         <source>Permission denied</source>
@@ -892,7 +892,7 @@ Check path and filename.</source>
     </message>
     <message>
         <source>Gujarati</source>
-        <translation></translation>
+        <translation>Гуджарати</translation>
     </message>
     <message>
         <source>Oriya</source>
@@ -932,7 +932,7 @@ Check path and filename.</source>
     </message>
     <message>
         <source>Myanmar</source>
-        <translation></translation>
+        <translation>Мьянма</translation>
     </message>
     <message>
         <source>Khmer</source>
@@ -1340,7 +1340,7 @@ Check path and filename.</source>
     </message>
     <message>
         <source>Select All</source>
-        <translation>Выделить все</translation>
+        <translation>Выделить всё</translation>
     </message>
 </context>
 <context>
@@ -1487,7 +1487,7 @@ to
     </message>
 </context>
 <context>
-    <name>QObject</name>
+    <name>TQObject</name>
     <message>
         <source>On The Spot</source>
         <translation></translation>
@@ -1565,7 +1565,7 @@ to
     </message>
     <message>
         <source>Print all</source>
-        <translation>Печатать все</translation>
+        <translation>Печатать всё</translation>
     </message>
     <message>
         <source>Print range</source>
@@ -1755,7 +1755,7 @@ to
     </message>
     <message>
         <source>bad char class syntax</source>
-        <translation>ошибочный синтаксис класса  символа</translation>
+        <translation>ошибочный синтаксис класса символа</translation>
     </message>
     <message>
         <source>bad lookahead syntax</source>
@@ -1876,7 +1876,7 @@ to
     </message>
     <message>
         <source>Select All</source>
-        <translation>Выделить все</translation>
+        <translation>Выделить всё</translation>
     </message>
 </context>
 <context>
@@ -2026,7 +2026,7 @@ to
     </message>
     <message>
         <source>&amp;Next &gt;</source>
-        <translation>&amp;Вперед &gt;</translation>
+        <translation>&amp;Вперёд &gt;</translation>
     </message>
     <message>
         <source>&amp;Finish</source>
